==> haskell-glib-0.13.8.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glib
version:              0.13.8.1
visibility:           public
id:                   glib-0.13.8.1-BbI48UwsLih7VH8HmkOZb4
key:                  glib-0.13.8.1-BbI48UwsLih7VH8HmkOZb4
license:              LGPL-2.1-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.

category:             System
abi:                  a06196434bcdfc630df97c3188ad46b7
exposed:              True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils

import-dirs:          /usr/lib/ghc-8.10.3/site-local/glib-0.13.8.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/glib-0.13.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/glib-0.13.8.1
hs-libraries:         HSglib-0.13.8.1-BbI48UwsLih7VH8HmkOZb4
extra-libraries:      gobject-2.0 glib-2.0
include-dirs:         /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1 text-1.2.4.1
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV

haddock-interfaces:   /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html:         /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glib-0.13.8.1-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glib
version:              0.13.8.1
visibility:           public
id:                   glib-0.13.8.1-6j6IeFHY7vPchmyxKyOqH
key:                  glib-0.13.8.1-6j6IeFHY7vPchmyxKyOqH
license:              LGPL-2.1-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.

category:             System
abi:                  da90ff2badaa9e2869392ba6487ef2e5
exposed:              True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/glib-0.13.8.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/glib-0.13.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/glib-0.13.8.1
hs-libraries:         HSglib-0.13.8.1-6j6IeFHY7vPchmyxKyOqH
extra-libraries:      gobject-2.0 glib-2.0
include-dirs:         /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1 text-1.2.4.1
    utf8-string-1.0.2-8tSNItKZaZx3RInHCj3b5n

haddock-interfaces:   /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html:         /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
